==> keycloak-model-map-18.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapIdentityProviderEntityDelegate.java <==
package org.keycloak.models.map.realm.entity;
public class MapIdentityProviderEntityDelegate implements org.keycloak.models.map.realm.entity.MapIdentityProviderEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapIdentityProviderEntity> delegateProvider;
    public MapIdentityProviderEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapIdentityProviderEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ID, id).setId(id);
    }
    @Override public String getAlias() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ALIAS).getAlias();
    }
    @Override public void setAlias(String alias) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ALIAS, alias).setAlias(alias);
    }
    @Override public String getDisplayName() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.DISPLAY_NAME).getDisplayName();
    }
    @Override public void setDisplayName(String displayName) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.DISPLAY_NAME, displayName).setDisplayName(displayName);
    }
    @Override public String getProviderId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.PROVIDER_ID).getProviderId();
    }
    @Override public void setProviderId(String providerId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.PROVIDER_ID, providerId).setProviderId(providerId);
    }
    @Override public String getFirstBrokerLoginFlowId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.FIRST_BROKER_LOGIN_FLOW_ID).getFirstBrokerLoginFlowId();
    }
    @Override public void setFirstBrokerLoginFlowId(String firstBrokerLoginFlowId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.FIRST_BROKER_LOGIN_FLOW_ID, firstBrokerLoginFlowId).setFirstBrokerLoginFlowId(firstBrokerLoginFlowId);
    }
    @Override public String getPostBrokerLoginFlowId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.POST_BROKER_LOGIN_FLOW_ID).getPostBrokerLoginFlowId();
    }
    @Override public void setPostBrokerLoginFlowId(String postBrokerLoginFlowId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.POST_BROKER_LOGIN_FLOW_ID, postBrokerLoginFlowId).setPostBrokerLoginFlowId(postBrokerLoginFlowId);
    }
    @Override public Boolean isEnabled() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ENABLED).isEnabled();
    }
    @Override public void setEnabled(Boolean enabled) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ENABLED, enabled).setEnabled(enabled);
    }
    @Override public Boolean isTrustEmail() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.TRUST_EMAIL).isTrustEmail();
    }
    @Override public void setTrustEmail(Boolean trustEmail) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.TRUST_EMAIL, trustEmail).setTrustEmail(trustEmail);
    }
    @Override public Boolean isStoreToken() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.STORE_TOKEN).isStoreToken();
    }
    @Override public void setStoreToken(Boolean storeToken) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.STORE_TOKEN, storeToken).setStoreToken(storeToken);
    }
    @Override public Boolean isLinkOnly() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.LINK_ONLY).isLinkOnly();
    }
    @Override public void setLinkOnly(Boolean linkOnly) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.LINK_ONLY, linkOnly).setLinkOnly(linkOnly);
    }
    @Override public Boolean isAddReadTokenRoleOnCreate() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ADD_READ_TOKEN_ROLE_ON_CREATE).isAddReadTokenRoleOnCreate();
    }
    @Override public void setAddReadTokenRoleOnCreate(Boolean addReadTokenRoleOnCreate) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ADD_READ_TOKEN_ROLE_ON_CREATE, addReadTokenRoleOnCreate).setAddReadTokenRoleOnCreate(addReadTokenRoleOnCreate);
    }
    @Override public Boolean isAuthenticateByDefault() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.AUTHENTICATE_BY_DEFAULT).isAuthenticateByDefault();
    }
    @Override public void setAuthenticateByDefault(Boolean authenticateByDefault) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.AUTHENTICATE_BY_DEFAULT, authenticateByDefault).setAuthenticateByDefault(authenticateByDefault);
    }
    @Override public java.util.Map<String,String> getConfig() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.CONFIG).getConfig();
    }
    @Override public void setConfig(java.util.Map<String,String> config) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.CONFIG, config).setConfig(config);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapIdentityProviderEntityDelegate.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapIdentityProviderEntityDelegate implements org.keycloak.models.map.realm.entity.MapIdentityProviderEntity, org.keycloak.models.map.common.delegate.HasDelegateProvider<org.keycloak.models.map.realm.entity.MapIdentityProviderEntity> {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapIdentityProviderEntity> delegateProvider;
    public MapIdentityProviderEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapIdentityProviderEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    public org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapIdentityProviderEntity> getDelegateProvider() {
        return this.delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ID, id).setId(id);
    }
    @Override public String getAlias() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ALIAS).getAlias();
    }
    @Override public void setAlias(String alias) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ALIAS, alias).setAlias(alias);
    }
    @Override public String getDisplayName() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.DISPLAY_NAME).getDisplayName();
    }
    @Override public void setDisplayName(String displayName) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.DISPLAY_NAME, displayName).setDisplayName(displayName);
    }
    @Override public String getProviderId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.PROVIDER_ID).getProviderId();
    }
    @Override public void setProviderId(String providerId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.PROVIDER_ID, providerId).setProviderId(providerId);
    }
    @Override public String getFirstBrokerLoginFlowId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.FIRST_BROKER_LOGIN_FLOW_ID).getFirstBrokerLoginFlowId();
    }
    @Override public void setFirstBrokerLoginFlowId(String firstBrokerLoginFlowId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.FIRST_BROKER_LOGIN_FLOW_ID, firstBrokerLoginFlowId).setFirstBrokerLoginFlowId(firstBrokerLoginFlowId);
    }
    @Override public String getPostBrokerLoginFlowId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.POST_BROKER_LOGIN_FLOW_ID).getPostBrokerLoginFlowId();
    }
    @Override public void setPostBrokerLoginFlowId(String postBrokerLoginFlowId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.POST_BROKER_LOGIN_FLOW_ID, postBrokerLoginFlowId).setPostBrokerLoginFlowId(postBrokerLoginFlowId);
    }
    @Override public Boolean isEnabled() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ENABLED).isEnabled();
    }
    @Override public void setEnabled(Boolean enabled) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ENABLED, enabled).setEnabled(enabled);
    }
    @Override public Boolean isTrustEmail() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.TRUST_EMAIL).isTrustEmail();
    }
    @Override public void setTrustEmail(Boolean trustEmail) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.TRUST_EMAIL, trustEmail).setTrustEmail(trustEmail);
    }
    @Override public Boolean isStoreToken() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.STORE_TOKEN).isStoreToken();
    }
    @Override public void setStoreToken(Boolean storeToken) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.STORE_TOKEN, storeToken).setStoreToken(storeToken);
    }
    @Override public Boolean isLinkOnly() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.LINK_ONLY).isLinkOnly();
    }
    @Override public void setLinkOnly(Boolean linkOnly) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.LINK_ONLY, linkOnly).setLinkOnly(linkOnly);
    }
    @Override public Boolean isAddReadTokenRoleOnCreate() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ADD_READ_TOKEN_ROLE_ON_CREATE).isAddReadTokenRoleOnCreate();
    }
    @Override public void setAddReadTokenRoleOnCreate(Boolean addReadTokenRoleOnCreate) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.ADD_READ_TOKEN_ROLE_ON_CREATE, addReadTokenRoleOnCreate).setAddReadTokenRoleOnCreate(addReadTokenRoleOnCreate);
    }
    @Override public Boolean isAuthenticateByDefault() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.AUTHENTICATE_BY_DEFAULT).isAuthenticateByDefault();
    }
    @Override public void setAuthenticateByDefault(Boolean authenticateByDefault) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.AUTHENTICATE_BY_DEFAULT, authenticateByDefault).setAuthenticateByDefault(authenticateByDefault);
    }
    @Override public java.util.Map<String,String> getConfig() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.CONFIG).getConfig();
    }
    @Override public void setConfig(java.util.Map<String,String> config) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderEntityFields.CONFIG, config).setConfig(config);
    }
}
